@@ -28,6 +28,22 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
   method DESTROY : void ();
 
+=head2 s6_addr
+
+  method s6_addr : string ();
+
+Gets C<s6_addr>. Its value is copied and a new string is created.
+
+=head2 set_s6_addr
+
+  method set_s6_addr : void ($address : string);
+
+Sets C<s6_addr>.
+
+The address must be defined. Otherwise an exception will be thrown.
+
+The length of the address must be less than or equal to 16. Otherwise an exception will be thrown.
+
 =head1 Copyright & License
 
 Copyright 2022-2022 Yuki Kimoto, all rights reserved.
